package org.tinyjee.maven.dim.sources;

import org.apache.velocity.app.VelocityEngine;
import org.apache.velocity.context.Context;
import org.apache.velocity.tools.config.EasyFactoryConfiguration;
import org.tinyjee.maven.dim.spi.Globals;
import org.tinyjee.maven.dim.spi.VelocityConfigurator;

import java.util.Map;

import static org.apache.velocity.runtime.RuntimeConstants.RESOURCE_LOADER;
import static org.apache.velocity.runtime.RuntimeConstants.VM_PERM_ALLOW_INLINE;

/**
 * Is the default implementation for {@link VelocityConfigurator} which sets various defaults.
 *
 * @author Juergen_Kellerer, 2011-10-14
 */
public class DefaultVelocityConfigurator implements VelocityConfigurator {
	public void configureEngine(VelocityEngine engine) {
		// START-SNIPPET: DefaultEngineConfiguration
		engine.setProperty(RESOURCE_LOADER, "dim-resource");
		engine.setProperty("dim-resource.resource.loader.class",
				"org.tinyjee.maven.dim.sources.TemplateSource$UrlResourceLoader");
		engine.setProperty(VM_PERM_ALLOW_INLINE, true);
		// END-SNIPPET: DefaultEngineConfiguration
	}

	public void configureTools(EasyFactoryConfiguration toolsConfiguration) {
		// START-SNIPPET: DefaultToolConfiguration
		toolsConfiguration.toolbox("application").
				tool("org.apache.velocity.tools.generic.AlternatorTool").
				tool("org.apache.velocity.tools.generic.ClassTool").
				tool("org.apache.velocity.tools.generic.ComparisonDateTool").
				tool("org.apache.velocity.tools.generic.ConversionTool").
				tool("org.apache.velocity.tools.generic.DisplayTool").
				tool("org.apache.velocity.tools.generic.EscapeTool").
				tool("org.apache.velocity.tools.generic.FieldTool").
				tool("org.apache.velocity.tools.generic.MathTool").
				tool("org.apache.velocity.tools.generic.NumberTool").
				tool("org.apache.velocity.tools.generic.SortTool").
				tool("org.apache.velocity.tools.generic.ListTool").
				tool("org.apache.velocity.tools.generic.ResourceTool").
				tool(VelocityHighlightingTool.class).
				tool(VelocitySourceClassInvocationTool.class);
		// END-SNIPPET: DefaultToolConfiguration
	}

	public void configureContext(Map<String, Object> parameters, Context templateContext) {
		// START-SNIPPET: DefaultContextConfiguration
		if (!parameters.containsKey("globals")) templateContext.put("globals", Globals.getInstance());
		if (!parameters.containsKey("macroParameters")) templateContext.put("macroParameters", parameters);
		// The parameter: 'sourceUrl' is set when the context is constructed and points to the actual template file.
		// END-SNIPPET: DefaultContextConfiguration
	}
}
