package org.tinyjee.maven.dim.sources;

import java.io.IOException;
import java.io.LineNumberReader;
import java.net.URL;
import java.util.Iterator;
import java.util.Map;

/**
 * Implements a selector that matches all snippet ID definitions triggered by a single expression "<b>snippet-ids</b>".
 * The purpose of this selector is to exclude any snippet id definitions from matched content.
 * <p/>
 * Example: "{@code %{include|snippet=#id-to-include, !snippet-ids}}".
 *
 * @author Juergen_Kellerer, 2011-10-16
 */
public class IdDefinitionSelector extends IdSnippetSelector {

	public IdDefinitionSelector() {
		super("snippet-ids");
	}

	@Override
	public boolean canSelectSnippetsWith(String expression, URL contentUrl, Map<String, Object> macroParameters) {
		return expressionPrefix.equalsIgnoreCase(expression);
	}

	@Override
	public Iterator<Integer> selectSnippets(String expression, URL contentUrl, LineNumberReader content,
	                                        Map<String, Object> macroParameters) throws IOException {
		assertExpressionIsValid(expression, contentUrl, macroParameters);

		return new AbstractStreamIterator<String>(expression, content) {
			@Override
			protected boolean isCapturingLine(boolean alreadyCapturing, String expression, String line, int lineNumber) {
				return isStart("", line) || isEnd("", line);
			}
		};
	}
}
